<?php

/**
 * @package "Image Watermark" Addon for Elkarte
 * @author Spuds
 * @copyright (c) 2020 Spuds
 * @license This Source Code is subject to the terms of the Mozilla Public License
 * version 1.1 (the "License"). You can obtain a copy of the License at
 * http://mozilla.org/MPL/1.1/.
 *
 * @version 1.0.0
 *
 */

/**
 * WatermarkAdmin_Controller class, deals with site settings for Watermark functions
 */
class WatermarkAdmin_Controller extends Action_Controller
{
	/**
	 * @var \Settings_Form
	 */
	var $watermark;

	public function pre_dispatch()
	{
		require_once(SUBSDIR . '/Action.class.php');
		require_once(SUBSDIR . '/Watermark.subs.php');

		loadLanguage('Watermark');

		parent::pre_dispatch();
	}

	/**
	 * Entry point in Watermark controller
	 */
	public function action_index()
	{
		// Where to go?  Well we only have one choice
		$subActions = array(
			'watermark' => array($this, 'action_watermark')
		);

		$action = new Action();

		// Default action is .... watermark
		$subAction = $action->initialize($subActions, 'watermark');

		// Go!
		$action->dispatch($subAction);
	}

	/**
	 * Shows all available watermark settings
	 */
	public function action_watermark()
	{
		global $txt, $context, $scripturl;

		// Initialize the form
		$this->_initwatermarksForm();

		$config_vars = $this->watermark->settings();

		// Setup the template
		$context['sub_template'] = 'show_settings';
		$context['page_title'] = $txt['watermark'];

		// Save them, show them
		if (isset($_GET['save']))
		{
			checkSession();
			$watermarkImages = watermarkDiscoverImages();
			Settings_Form::save_db($config_vars);

			updateSettings(array('watermarkImageFile' => $watermarkImages[$_POST['watermarkImage']]));
			redirectexit('action=admin;area=manageattachments;sa=watermark');
		}

		$context['post_url'] = $scripturl . '?action=admin;area=manageattachments;save;sa=watermark';
		$context['settings_title'] = $txt['watermark'];

		Settings_Form::prepare_db($config_vars);
	}

	/**
	 * Initialize settings form with the configuration settings
	 */
	private function _initwatermarksForm()
	{
		// This is really quite wanting.
		require_once(SUBSDIR . '/SettingsForm.class.php');

		// Instantiate the form
		$this->watermark = new Settings_Form();

		// Initialize it with our settings
		$config_vars = $this->_watermarkSettings();

		return $this->watermark->settings($config_vars);
	}

	/**
	 * Return configuration settings
	 */
	private function _watermarkSettings()
	{
		global $txt;

		// These are the images we have available
		$watermarkImages = watermarkDiscoverImages();
		$check = class_exists('Imagick') && class_exists('ImagickDraw') && class_exists('ImagickPixel');
		$image = '';

		// Missing dependency, make sure this is off
		if (!$check)
		{
			updateSettings(array('watermarkEnabled' => 0));
		}
		else
		{
			$image = processWatermark(BOARDDIR . '/themes/default/images/watermark/admin_example.jpg', 'image/jpg', false);
		}

		return array(
			array('check', 'watermarkEnabled', 'postinput' => empty($check) ? $txt['watermarkImagick'] : '', 'disabled' => !$check),
			'',
			array('select', 'watermarkImage', $watermarkImages),
			array('text', 'watermarkScaleHeight', 'postinput' => $txt['px_%']),
			array('text', 'watermarkScaleWidth', 'postinput' => $txt['px_%']),
			'',
			array('text', 'watermarkText'),
			array('text', 'watermarkTextSize', 'postinput' => $txt['pt_%']),
			array('int', 'watermarkStrokeSize', 'postinput' => '( pt )'),
			'',
			array('int', 'watermarkMinHeight', 'postinput' => $txt['watermarkPixels']),
			array('int', 'watermarkMinWidth', 'postinput' => $txt['watermarkPixels']),
			array(
				'select', 'watermarkPosition', array(
					1 => $txt['watermarkPositionTopLeft'],
					$txt['watermarkPositionTopCenter'],
					$txt['watermarkPositionTopRight'],
					$txt['watermarkPositionCenterLeft'],
					$txt['watermarkPositionCenter'],
					$txt['watermarkPositionCenterRight'],
					$txt['watermarkPositionBottomLeft'],
					$txt['watermarkPositionBottomCenter'],
					$txt['watermarkPositionBottomRight'],
				),
			),
			'',
			array('check', 'name' => 'adminsample', 'disabled' => true,
				  $txt['watermarkTestExample'] . '<br><img src="data:image/jpg;base64,' . base64_encode($image) . '" />'),
		);
	}

	/**
	 * Return the settings for use in admin search
	 */
	public function settings_search()
	{
		return $this->_watermarkSettings();
	}
}
